==> lxqt-panel_2.0.1.orig.tar.xz: lxqt-panel-2.0.1/plugin-fancymenu/translations/fancymenu_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Laga/kisa menyu eya bulijjo</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>By&apos;ojjumbira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="55"/>
        <source>All Applications</source>
        <translation>Puloguramu zonna</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu settings</source>
        <translation>Enteekateeka za menyu ey&apos;ak&apos;ensusso</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Eby&apos;awamu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Kafaananyi:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Ebigambo ebya ku ppeesa:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Obunene bw&apos;ennukuta:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="105"/>
        <source>Menu file</source>
        <translation>Fayiro omuva menyu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="111"/>
        <source>Menu file:</source>
        <translation>Fayiro omuva menyu:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="127"/>
        <source>Keyboard Shortcut</source>
        <translation>mapeesa agagonza emirimu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="146"/>
        <source>Click the button to record shortcut:</source>
        <translation>Nyiga ku mapeesa aganaagonzanga emirimu:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Search</source>
        <translation>Noonya</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="162"/>
        <source>Clear search upon showing menu</source>
        <translation>Menyu olulabika olukalala lw&apos;ebizuulidwa luveewo</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="172"/>
        <source>Popup</source>
        <translation>Kuboneka</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="181"/>
        <source>Buttons row position</source>
        <translation>Amapeesa wegaba galabikira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="188"/>
        <source>Categories position</source>
        <translation>Ebiti webirabikira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Komyawo ebyasooka</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="104"/>
        <source>Bottom</source>
        <translation>Wansi</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="105"/>
        <source>Top</source>
        <translation>Waggulu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="110"/>
        <source>Left</source>
        <translation>Ku kkono</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Right</source>
        <translation>Ku ddyo</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="169"/>
        <source>Choose icon file</source>
        <translation>Londa fayiro ey&apos;akafaananyi</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="171"/>
        <source>Images (*.svg *.png)</source>
        <translation>Bifaananyi (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="183"/>
        <source>Choose menu file</source>
        <translation>Londa fayiro omuva menyu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="185"/>
        <source>Menu files (*.menu)</source>
        <translation>Fayiro ezirimu menyu (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="135"/>
        <source>Search...</source>
        <translation>Noonya...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="142"/>
        <source>Settings</source>
        <translation>Enteekateeka</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="148"/>
        <source>Leave</source>
        <translation>Mala</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="295"/>
        <source>Add to desktop</source>
        <translation>Teeka awakolerwa</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="303"/>
        <source>Question</source>
        <translation>Kubuuza</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="304"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Fayiro ey&apos;erinnya eryo gy&apos;eri.
Oyagala okugigyawo ozewo eno?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="310"/>
        <source>Warning</source>
        <translation>Kulabula</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="311"/>
        <source>The file cannot be overwritten.</source>
        <translation>Fayiro esobola okugyibwawo kuzzawo ndala.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="318"/>
        <source>Copy</source>
        <translation>Koppa</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="331"/>
        <source>Remove from Favorites</source>
        <translation>Gigye mu by&apos;ojjumbira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="338"/>
        <source>Add to Favorites</source>
        <translation>Gyongere ku by&apos;ojjumbira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="433"/>
        <source>No Executable</source>
        <translation>Tewali puloguramu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="434"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation>Puloguramu &lt;b&gt;%1&lt;/b&gt; embuze.</translation>
    </message>
</context>
</TS>

==> lxqt-panel_2.2.2.orig.tar.xz: lxqt-panel-2.2.2/plugin-fancymenu/translations/fancymenu_lg.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="lg">
<context>
    <name>LXQtFancyMenu</name>
    <message>
        <location filename="../lxqtfancymenu.cpp" line="93"/>
        <source>Show/hide main menu</source>
        <translation>Laga/kisa menyu eya bulijjo</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuAppMapStrings</name>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="49"/>
        <source>Favorites</source>
        <translation>By&apos;ojjumbira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuappmap.cpp" line="56"/>
        <source>All Applications</source>
        <translation>Puloguramu zonna</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuConfiguration</name>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="14"/>
        <source>Fancy Menu Settings</source>
        <translation>Enteekateeka za menyu ey&apos;ak&apos;ensusso</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="20"/>
        <source>General</source>
        <translation>Eby&apos;awamu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="35"/>
        <source>Icon:</source>
        <translation>Kafaananyi:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="59"/>
        <source>Button text:</source>
        <translation>Ebigambo ebya ku ppeesa:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="76"/>
        <source>Custom font size:</source>
        <translation>Obunene bw&apos;ennukuta:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="86"/>
        <source> pt</source>
        <translation> pt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="99"/>
        <source>Auto-select after:</source>
        <translation>Sisitemu eronde kino bwe wayitawo ebbanga lya:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="109"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="134"/>
        <source>Menu file</source>
        <translation>Fayiro omuva menyu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="140"/>
        <source>Menu file:</source>
        <translation>Fayiro omuva menyu:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="156"/>
        <source>Keyboard Shortcut</source>
        <translation>mapeesa agagonza emirimu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="175"/>
        <source>Click the button to record shortcut:</source>
        <translation>Nyiga ku mapeesa aganaagonzanga emirimu:</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="185"/>
        <source>Search</source>
        <translation>Noonya</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="191"/>
        <source>Clear search upon showing menu</source>
        <translation>Menyu olulabika olukalala lw&apos;ebizuulidwa luveewo</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="201"/>
        <source>Layout</source>
        <translation>Entegeka</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="210"/>
        <source>Buttons row position</source>
        <translation>Amapeesa wegaba galabikira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.ui" line="217"/>
        <source>Categories position</source>
        <translation>Ebiti webirabikira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="81"/>
        <source>Reset</source>
        <translation>Komyawo ebyasooka</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="111"/>
        <source>Bottom</source>
        <translation>Wansi</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="112"/>
        <source>Top</source>
        <translation>Waggulu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="117"/>
        <source>Left</source>
        <translation>Ku kkono</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="118"/>
        <source>Right</source>
        <translation>Ku ddyo</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="179"/>
        <source>Choose icon file</source>
        <translation>Londa fayiro ey&apos;akafaananyi</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="181"/>
        <source>Images (*.svg *.png)</source>
        <translation>Bifaananyi (*.svg *.png)</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="193"/>
        <source>Choose menu file</source>
        <translation>Londa fayiro omuva menyu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuconfiguration.cpp" line="195"/>
        <source>Menu files (*.menu)</source>
        <translation>Fayiro ezirimu menyu (*.menu)</translation>
    </message>
</context>
<context>
    <name>LXQtFancyMenuWindow</name>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="155"/>
        <source>Search...</source>
        <translation>Noonya...</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="161"/>
        <source>LXQt Configuration Center</source>
        <translation>Entabiro y&apos;enteekateeka eza LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="167"/>
        <source>Leave</source>
        <translation>Mala</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="173"/>
        <source>About LXQt</source>
        <translation>Ebifa ku LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="191"/>
        <source>Add your favorites by right clicking items from categories.</source>
        <translation>Ky&apos;olabye ku lukalala lw&apos;ekiti okukiteeka ne ku lukalala lwa by&apos;ojjumbira, kiteekeko akasonga onyige eppeesa ery&apos;akasongesebwa erya ddyo.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="357"/>
        <source>Add to desktop</source>
        <translation>Teeka awakolerwa</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="365"/>
        <source>Question</source>
        <translation>Kubuuza</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="366"/>
        <source>A file with the same name already exists.
Do you want to overwrite it?</source>
        <translation>Fayiro ey&apos;erinnya eryo gy&apos;eri.
Oyagala okugigyawo ozewo eno?</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="372"/>
        <source>Warning</source>
        <translation>Kulabula</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="373"/>
        <source>The file cannot be overwritten.</source>
        <translation>Fayiro esobola okugyibwawo kuzzawo ndala.</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="380"/>
        <source>Copy</source>
        <translation>Koppa</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="393"/>
        <source>Remove from Favorites</source>
        <translation>Gigye mu by&apos;ojjumbira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="400"/>
        <source>Add to Favorites</source>
        <translation>Gyongere ku by&apos;ojjumbira</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="716"/>
        <source>No Executable</source>
        <translation>Tewali puloguramu</translation>
    </message>
    <message>
        <location filename="../lxqtfancymenuwindow.cpp" line="717"/>
        <source>Cannot find &lt;b&gt;%1&lt;/b&gt; executable.</source>
        <translation>Puloguramu &lt;b&gt;%1&lt;/b&gt; embuze.</translation>
    </message>
</context>
</TS>
